@@ -18,13 +18,17 @@ class NsqReader(Reader):
     def run(self, callback):
         def _mission(message):
             if message.body:
-                callback(message.body, message=message)
+                is_finish = callback(message.body, message=message)
+                if is_finish==True:
+                    message.finish()
+            else:
+                message.finish()
 
-            message.finish()
+            return True
 
         nsq.Reader(
             message_handler=_mission,
             **self.options
         )
 
-        nsq.run()       
\ No newline at end of file
+        nsq.run()      
\ No newline at end of file
